==> embiggen-0.11.18.tar.gz: embiggen-0.11.18/embiggen/embedders/pykeen_embedders/cp.py <==
"""Submodule providing wrapper for PyKeen's CP model."""
from typing import Union, Type, Dict, Any, Optional
from pykeen.training import TrainingLoop
from pykeen.models import CP
from embiggen.embedders.pykeen_embedders.entity_relation_embedding_model_pykeen import EntityRelationEmbeddingModelPyKeen
from pykeen.triples import CoreTriplesFactory


class CPPyKeen(EntityRelationEmbeddingModelPyKeen):

    def __init__(
        self,
        embedding_size: int = 256,
        rank: int = 64,
        epochs: int = 100,
        batch_size: int = 2**10,
        training_loop: Union[str, Type[TrainingLoop]
                             ] = "Stochastic Local Closed World Assumption",
        verbose: bool = False,
        random_state: int = 42,
        enable_cache: bool = False
    ):
        """Create new PyKeen CP model.

        Details
        -------------------------
        This is a wrapper of the CP implementation from the
        PyKeen library. Please refer to the PyKeen library documentation
        for details and posssible errors regarding this model.

        Parameters
        -------------------------
        embedding_size: int = 256
            The dimension of the embedding to compute.
        rank: int = 64
            The hidden dropout rate
        epochs: int = 100
            The number of epochs to use to train the model for.
        batch_size: int = 2**10
            Size of the training batch.
        device: str = "auto"
            The devide to use to train the model.
            Can either be cpu or cuda.
        training_loop: Union[str, Type[TrainingLoop]
                             ] = "Stochastic Local Closed World Assumption"
            The training loop to use to train the model.
            Can either be:
            - Stochastic Local Closed World Assumption
            - Local Closed World Assumption
        verbose: bool = False
            Whether to show loading bars.
        random_state: int = 42
            Random seed to use while training the model
        enable_cache: bool = False
            Whether to enable the cache, that is to
            store the computed embedding.
        """
        self._rank = rank
        super().__init__(
            embedding_size=embedding_size,
            epochs=epochs,
            batch_size=batch_size,
            training_loop=training_loop,
            verbose=verbose,
            random_state=random_state,
            enable_cache=enable_cache
        )

    def parameters(self) -> Dict[str, Any]:
        return dict(
            **super().parameters(),
            **dict(
                rank=self._rank,
            )
        )

    @classmethod
    def model_name(cls) -> str:
        """Return name of the model."""
        return "CP"

    def _build_model(
        self,
        triples_factory: CoreTriplesFactory
    ) -> CP:
        """Build new CP model for embedding.

        Parameters
        ------------------
        graph: Graph
            The graph to build the model for.
        """
        return CP(
            triples_factory=triples_factory,
            embedding_dim=self._embedding_size,
            rank=self._rank,
            random_seed=self._random_state
        )

==> embiggen-0.11.19.tar.gz: embiggen-0.11.19/embiggen/embedders/pykeen_embedders/cp.py <==
"""Submodule providing wrapper for PyKEEN's CP model."""
from typing import Union, Type, Dict, Any, Optional
from pykeen.training import TrainingLoop
from pykeen.models import CP
from embiggen.embedders.pykeen_embedders.entity_relation_embedding_model_pykeen import EntityRelationEmbeddingModelPyKEEN
from pykeen.triples import CoreTriplesFactory


class CPPyKEEN(EntityRelationEmbeddingModelPyKEEN):

    def __init__(
        self,
        embedding_size: int = 256,
        rank: int = 64,
        epochs: int = 100,
        batch_size: int = 2**10,
        training_loop: Union[str, Type[TrainingLoop]
                             ] = "Stochastic Local Closed World Assumption",
        verbose: bool = False,
        random_state: int = 42,
        enable_cache: bool = False
    ):
        """Create new PyKEEN CP model.

        Details
        -------------------------
        This is a wrapper of the CP implementation from the
        PyKEEN library. Please refer to the PyKEEN library documentation
        for details and posssible errors regarding this model.

        Parameters
        -------------------------
        embedding_size: int = 256
            The dimension of the embedding to compute.
        rank: int = 64
            The hidden dropout rate
        epochs: int = 100
            The number of epochs to use to train the model for.
        batch_size: int = 2**10
            Size of the training batch.
        device: str = "auto"
            The devide to use to train the model.
            Can either be cpu or cuda.
        training_loop: Union[str, Type[TrainingLoop]
                             ] = "Stochastic Local Closed World Assumption"
            The training loop to use to train the model.
            Can either be:
            - Stochastic Local Closed World Assumption
            - Local Closed World Assumption
        verbose: bool = False
            Whether to show loading bars.
        random_state: int = 42
            Random seed to use while training the model
        enable_cache: bool = False
            Whether to enable the cache, that is to
            store the computed embedding.
        """
        self._rank = rank
        super().__init__(
            embedding_size=embedding_size,
            epochs=epochs,
            batch_size=batch_size,
            training_loop=training_loop,
            verbose=verbose,
            random_state=random_state,
            enable_cache=enable_cache
        )

    def parameters(self) -> Dict[str, Any]:
        return dict(
            **super().parameters(),
            **dict(
                rank=self._rank,
            )
        )

    @classmethod
    def model_name(cls) -> str:
        """Return name of the model."""
        return "CP"

    def _build_model(
        self,
        triples_factory: CoreTriplesFactory
    ) -> CP:
        """Build new CP model for embedding.

        Parameters
        ------------------
        graph: Graph
            The graph to build the model for.
        """
        return CP(
            triples_factory=triples_factory,
            embedding_dim=self._embedding_size,
            rank=self._rank,
            random_seed=self._random_state
        )
